@@ -15,18 +15,17 @@ typedef struct {
 skipped_corpus_test_t SKIPPED_CORPUS_TESTS[] = {
    /* CDRIVER-1879, can't make Code with embedded NIL */
    {"Javascript Code", "Embedded nulls"},
-   {"Javascript Code with Scope",
-    "Unicode and embedded null in code string, empty scope"},
+   {"Javascript Code with Scope", "Unicode and embedded null in code string, empty scope"},
    /* CDRIVER-2223, legacy extended JSON $date syntax uses numbers */
    {"Top-level document validity", "Bad $date (number, not string or hash)"},
    /* CDRIVER-3500, floating point output differs */
    {"Double type", "1.2345678921232E+18"},
    {"Double type", "-1.2345678921232E+18"},
    /* CDRIVER-4017, libbson does not emit escape sequences */
-   {"Javascript Code", "two-byte UTF-8 (\xc3\xa9)"}, /* \u00e9 */
+   {"Javascript Code", "two-byte UTF-8 (\xc3\xa9)"},       /* \u00e9 */
    {"Javascript Code", "three-byte UTF-8 (\xe2\x98\x86)"}, /* \u2606 */
-   {"String", "two-byte UTF-8 (\xc3\xa9)"}, /* \u00e9 */
-   {"String", "three-byte UTF-8 (\xe2\x98\x86)"}, /* \u2606 */
+   {"String", "two-byte UTF-8 (\xc3\xa9)"},                /* \u00e9 */
+   {"String", "three-byte UTF-8 (\xe2\x98\x86)"},          /* \u2606 */
    {0}};
 
 
@@ -38,10 +37,7 @@ skipped_corpus_test_t VS2013_SKIPPED_CORPUS_TESTS[] = {
 
 
 static void
-compare_data (const uint8_t *a,
-              uint32_t a_len,
-              const uint8_t *b,
-              uint32_t b_len)
+compare_data (const uint8_t *a, uint32_t a_len, const uint8_t *b, uint32_t b_len)
 {
    bson_string_t *a_str;
    bson_string_t *b_str;
@@ -58,12 +54,7 @@ compare_data (const uint8_t *a,
          bson_string_append_printf (b_str, "%02X", (int) b[i]);
       }
 
-      fprintf (stderr,
-               "unequal data of length %d and %d:\n%s\n%s\n",
-               a_len,
-               b_len,
-               a_str->str,
-               b_str->str);
+      fprintf (stderr, "unequal data of length %d and %d:\n%s\n%s\n", a_len, b_len, a_str->str, b_str->str);
 
       abort ();
    }
@@ -76,8 +67,7 @@ is_test_skipped (const char *scenario, const char *description)
    skipped_corpus_test_t *skip;
 
    for (skip = SKIPPED_CORPUS_TESTS; skip->scenario != NULL; skip++) {
-      if (!strcmp (skip->scenario, scenario) &&
-          !strcmp (skip->test, description)) {
+      if (!strcmp (skip->scenario, scenario) && !strcmp (skip->test, description)) {
          return true;
       }
    }
@@ -85,8 +75,7 @@ is_test_skipped (const char *scenario, const char *description)
 /* _MSC_VER 1900 is Visual Studio 2015 */
 #if (defined(_MSC_VER) && _MSC_VER < 1900)
    for (skip = VS2013_SKIPPED_CORPUS_TESTS; skip->scenario != NULL; skip++) {
-      if (!strcmp (skip->scenario, scenario) &&
-          !strcmp (skip->test, description)) {
+      if (!strcmp (skip->scenario, scenario) && !strcmp (skip->test, description)) {
          return true;
       }
    }
@@ -153,8 +142,7 @@ test_bson_corpus_valid (test_bson_valid_type_t *test)
    ASSERT_OR_PRINT (decode_cE, error);
 
    if (!test->lossy) {
-      compare_data (
-         bson_get_data (decode_cE), decode_cE->len, test->cB, test->cB_len);
+      compare_data (bson_get_data (decode_cE), decode_cE->len, test->cB, test->cB_len);
    }
 
    if (test->dB) {
@@ -172,12 +160,10 @@ test_bson_corpus_valid (test_bson_valid_type_t *test)
       decode_dE = bson_new_from_json ((const uint8_t *) test->dE, -1, &error);
 
       ASSERT_OR_PRINT (decode_dE, error);
-      ASSERT_CMPJSON (bson_as_canonical_extended_json (decode_dE, NULL),
-                      test->cE);
+      ASSERT_CMPJSON (bson_as_canonical_extended_json (decode_dE, NULL), test->cE);
 
       if (!test->lossy) {
-         compare_data (
-            bson_get_data (decode_dE), decode_dE->len, test->cB, test->cB_len);
+         compare_data (bson_get_data (decode_dE), decode_dE->len, test->cB, test->cB_len);
       }
 
       bson_destroy (decode_dE);
@@ -187,8 +173,7 @@ test_bson_corpus_valid (test_bson_valid_type_t *test)
       decode_rE = bson_new_from_json ((const uint8_t *) test->rE, -1, &error);
 
       ASSERT_OR_PRINT (decode_rE, error);
-      ASSERT_CMPJSON (bson_as_relaxed_extended_json (decode_rE, NULL),
-                      test->rE);
+      ASSERT_CMPJSON (bson_as_relaxed_extended_json (decode_rE, NULL), test->rE);
 
       bson_destroy (decode_rE);
    }
@@ -220,8 +205,7 @@ test_bson_corpus_decode_error (test_bson_decode_error_type_t *test)
    }
 
    ASSERT (test->bson);
-   ASSERT (!bson_init_static (&invalid_bson, test->bson, test->bson_len) ||
-           bson_empty (&invalid_bson) ||
+   ASSERT (!bson_init_static (&invalid_bson, test->bson, test->bson_len) || bson_empty (&invalid_bson) ||
            !bson_as_canonical_extended_json (&invalid_bson, NULL));
 }
 
@@ -285,14 +269,12 @@ test_bson_corpus_parse_error (test_bson_parse_error_type_t *test)
 static void
 test_bson_corpus_cb (bson_t *scenario)
 {
-   corpus_test (scenario,
-                test_bson_corpus_valid,
-                test_bson_corpus_decode_error,
-                test_bson_corpus_parse_error);
+   corpus_test (scenario, test_bson_corpus_valid, test_bson_corpus_decode_error, test_bson_corpus_parse_error);
 }
 
 static void
-test_bson_corpus_prose_1 (void) {
+test_bson_corpus_prose_1 (void)
+{
    bson_t *bson;
    bool ok;
    bson_t subdoc;
@@ -304,7 +286,7 @@ test_bson_corpus_prose_1 (void) {
    bson_destroy (bson);
 
    /* Field name within a sub-document */
-   bson = bson_new();
+   bson = bson_new ();
    bson_append_document_begin (bson, "subdoc", -1, &subdoc);
    ok = bson_append_int32 (&subdoc, "a\0b", 3, 123);
    BSON_ASSERT (!ok);
@@ -324,7 +306,6 @@ test_bson_corpus_prose_1 (void) {
 void
 test_bson_corpus_install (TestSuite *suite)
 {
-   install_json_test_suite_with_check (
-      suite, BSON_JSON_DIR, "bson_corpus", test_bson_corpus_cb);
+   install_json_test_suite_with_check (suite, BSON_JSON_DIR, "bson_corpus", test_bson_corpus_cb);
    TestSuite_Add (suite, "/bson_corpus/prose_1", test_bson_corpus_prose_1);
 }
