@@ -55,8 +55,7 @@ mongoc_cmd_parts_init (mongoc_cmd_parts_t *parts,
    parts->assembled.command = NULL;
    parts->assembled.query_flags = MONGOC_QUERY_NONE;
    parts->assembled.op_msg_is_exhaust = false;
-   parts->assembled.payload_identifier = NULL;
-   parts->assembled.payload = NULL;
+   parts->assembled.payloads_count = 0;
    parts->assembled.session = NULL;
    parts->assembled.is_acknowledged = true;
    parts->assembled.is_txn_finish = false;
@@ -78,8 +77,7 @@ mongoc_cmd_parts_init (mongoc_cmd_parts_t *parts,
  */
 
 void
-mongoc_cmd_parts_set_session (mongoc_cmd_parts_t *parts,
-                              mongoc_client_session_t *cs)
+mongoc_cmd_parts_set_session (mongoc_cmd_parts_t *parts, mongoc_client_session_t *cs)
 {
    BSON_ASSERT (parts);
    BSON_ASSERT (!parts->assembled.command);
@@ -109,9 +107,7 @@ mongoc_cmd_parts_set_session (mongoc_cmd_parts_t *parts,
  */
 
 bool
-mongoc_cmd_parts_append_opts (mongoc_cmd_parts_t *parts,
-                              bson_iter_t *iter,
-                              bson_error_t *error)
+mongoc_cmd_parts_append_opts (mongoc_cmd_parts_t *parts, bson_iter_t *iter, bson_error_t *error)
 {
    mongoc_client_session_t *cs = NULL;
    mongoc_write_concern_t *wc;
@@ -141,10 +137,7 @@ mongoc_cmd_parts_append_opts (mongoc_cmd_parts_t *parts,
          continue;
       } else if (BSON_ITER_IS_KEY (iter, "readConcern")) {
          if (!BSON_ITER_HOLDS_DOCUMENT (iter)) {
-            bson_set_error (error,
-                            MONGOC_ERROR_COMMAND,
-                            MONGOC_ERROR_PROTOCOL_BAD_WIRE_VERSION,
-                            "Invalid readConcern");
+            bson_set_error (error, MONGOC_ERROR_COMMAND, MONGOC_ERROR_PROTOCOL_BAD_WIRE_VERSION, "Invalid readConcern");
             RETURN (false);
          }
 
@@ -157,15 +150,13 @@ mongoc_cmd_parts_append_opts (mongoc_cmd_parts_t *parts,
       } else if (BSON_ITER_IS_KEY (iter, "sessionId")) {
          BSON_ASSERT (!parts->assembled.session);
 
-         if (!_mongoc_client_session_from_iter (
-                parts->client, iter, &cs, error)) {
+         if (!_mongoc_client_session_from_iter (parts->client, iter, &cs, error)) {
             RETURN (false);
          }
 
          parts->assembled.session = cs;
          continue;
-      } else if (BSON_ITER_IS_KEY (iter, "serverId") ||
-                 BSON_ITER_IS_KEY (iter, "maxAwaitTimeMS") ||
+      } else if (BSON_ITER_IS_KEY (iter, "serverId") || BSON_ITER_IS_KEY (iter, "maxAwaitTimeMS") ||
                  BSON_ITER_IS_KEY (iter, "exhaust")) {
          continue;
       }
@@ -185,19 +176,16 @@ mongoc_cmd_parts_append_opts (mongoc_cmd_parts_t *parts,
 }
 
 
-#define OPTS_ERR(_code, ...)                                              \
-   do {                                                                   \
-      bson_set_error (                                                    \
-         error, MONGOC_ERROR_COMMAND, MONGOC_ERROR_##_code, __VA_ARGS__); \
-      RETURN (false);                                                     \
+#define OPTS_ERR(_code, ...)                                                           \
+   do {                                                                                \
+      bson_set_error (error, MONGOC_ERROR_COMMAND, MONGOC_ERROR_##_code, __VA_ARGS__); \
+      RETURN (false);                                                                  \
    } while (0)
 
 
 /* set readConcern if allowed, otherwise error */
 bool
-mongoc_cmd_parts_set_read_concern (mongoc_cmd_parts_t *parts,
-                                   const mongoc_read_concern_t *rc,
-                                   bson_error_t *error)
+mongoc_cmd_parts_set_read_concern (mongoc_cmd_parts_t *parts, const mongoc_read_concern_t *rc, bson_error_t *error)
 {
    const char *command_name;
 
@@ -222,8 +210,7 @@ mongoc_cmd_parts_set_read_concern (mongoc_cmd_parts_t *parts,
    }
 
    bson_destroy (&parts->read_concern_document);
-   bson_copy_to (_mongoc_read_concern_get_bson ((mongoc_read_concern_t *) rc),
-                 &parts->read_concern_document);
+   bson_copy_to (_mongoc_read_concern_get_bson ((mongoc_read_concern_t *) rc), &parts->read_concern_document);
 
    RETURN (true);
 }
@@ -232,9 +219,7 @@ mongoc_cmd_parts_set_read_concern (mongoc_cmd_parts_t *parts,
 /* set writeConcern if allowed, otherwise ignore - unlike set_read_concern, it's
  * the caller's responsibility to check if writeConcern is supported */
 bool
-mongoc_cmd_parts_set_write_concern (mongoc_cmd_parts_t *parts,
-                                    const mongoc_write_concern_t *wc,
-                                    bson_error_t *error)
+mongoc_cmd_parts_set_write_concern (mongoc_cmd_parts_t *parts, const mongoc_write_concern_t *wc, bson_error_t *error)
 {
    ENTRY;
 
@@ -250,8 +235,7 @@ mongoc_cmd_parts_set_write_concern (mongoc_cmd_parts_t *parts,
 
    parts->assembled.is_acknowledged = mongoc_write_concern_is_acknowledged (wc);
    bson_destroy (&parts->write_concern_document);
-   bson_copy_to (_mongoc_write_concern_get_bson ((mongoc_write_concern_t *) wc),
-                 &parts->write_concern_document);
+   bson_copy_to (_mongoc_write_concern_get_bson ((mongoc_write_concern_t *) wc), &parts->write_concern_document);
 
    RETURN (true);
 }
@@ -277,9 +261,7 @@ mongoc_cmd_parts_set_write_concern (mongoc_cmd_parts_t *parts,
  */
 
 bool
-mongoc_cmd_parts_append_read_write (mongoc_cmd_parts_t *parts,
-                                    mongoc_read_write_opts_t *rw_opts,
-                                    bson_error_t *error)
+mongoc_cmd_parts_append_read_write (mongoc_cmd_parts_t *parts, mongoc_read_write_opts_t *rw_opts, bson_error_t *error)
 {
    ENTRY;
 
@@ -287,14 +269,12 @@ mongoc_cmd_parts_append_read_write (mongoc_cmd_parts_t *parts,
    BSON_ASSERT (!parts->assembled.command);
 
    if (!bson_empty (&rw_opts->collation)) {
-      if (!bson_append_document (
-             &parts->extra, "collation", 9, &rw_opts->collation)) {
+      if (!bson_append_document (&parts->extra, "collation", 9, &rw_opts->collation)) {
          OPTS_ERR (COMMAND_INVALID_ARG, "'opts' with 'collation' is too large");
       }
    }
 
-   if (!mongoc_cmd_parts_set_write_concern (
-          parts, rw_opts->writeConcern, error)) {
+   if (!mongoc_cmd_parts_set_write_concern (parts, rw_opts->writeConcern, error)) {
       RETURN (false);
    }
 
@@ -335,18 +315,14 @@ _mongoc_cmd_parts_add_write_concern (mongoc_cmd_parts_t *parts)
 {
    if (!bson_empty (&parts->write_concern_document)) {
       _mongoc_cmd_parts_ensure_copied (parts);
-      bson_append_document (&parts->assembled_body,
-                            "writeConcern",
-                            12,
-                            &parts->write_concern_document);
+      bson_append_document (&parts->assembled_body, "writeConcern", 12, &parts->write_concern_document);
    }
 }
 
 
 /* The server type must be mongos, or message must be OP_MSG. */
 static void
-_mongoc_cmd_parts_add_read_prefs (bson_t *query,
-                                  const mongoc_read_prefs_t *prefs)
+_mongoc_cmd_parts_add_read_prefs (bson_t *query, const mongoc_read_prefs_t *prefs)
 {
    bson_t child;
    const char *mode_str;
@@ -393,8 +369,7 @@ _iter_concat (bson_t *dst, bson_iter_t *iter)
 /* Update result with the read prefs. Server must be mongos.
  */
 static void
-_mongoc_cmd_parts_assemble_mongos (mongoc_cmd_parts_t *parts,
-                                   const mongoc_server_stream_t *server_stream)
+_mongoc_cmd_parts_assemble_mongos (mongoc_cmd_parts_t *parts, const mongoc_server_stream_t *server_stream)
 {
    mongoc_read_mode_t mode;
    const bson_t *tags = NULL;
@@ -411,8 +386,7 @@ _mongoc_cmd_parts_assemble_mongos (mongoc_cmd_parts_t *parts,
 
    mode = mongoc_read_prefs_get_mode (parts->read_prefs);
    if (parts->read_prefs) {
-      max_staleness_seconds =
-         mongoc_read_prefs_get_max_staleness_seconds (parts->read_prefs);
+      max_staleness_seconds = mongoc_read_prefs_get_max_staleness_seconds (parts->read_prefs);
 
       tags = mongoc_read_prefs_get_tags (parts->read_prefs);
       hedge = mongoc_read_prefs_get_hedge (parts->read_prefs);
@@ -449,8 +423,7 @@ _mongoc_cmd_parts_assemble_mongos (mongoc_cmd_parts_t *parts,
    case MONGOC_READ_PRIMARY:
       break;
    case MONGOC_READ_SECONDARY_PREFERRED:
-      if (!bson_empty0 (tags) || max_staleness_seconds > 0 ||
-          !bson_empty0 (hedge)) {
+      if (!bson_empty0 (tags) || max_staleness_seconds > 0 || !bson_empty0 (hedge)) {
          add_read_prefs = true;
       }
       parts->assembled.query_flags |= MONGOC_QUERY_SECONDARY_OK;
@@ -464,8 +437,7 @@ _mongoc_cmd_parts_assemble_mongos (mongoc_cmd_parts_t *parts,
    }
 
    requires_read_concern =
-      !bson_empty (&parts->read_concern_document) &&
-      strcmp (parts->assembled.command_name, "getMore") != 0;
+      !bson_empty (&parts->read_concern_document) && strcmp (parts->assembled.command_name, "getMore") != 0;
 
    requires_write_concern = !bson_empty (&parts->write_concern_document);
 
@@ -483,23 +455,19 @@ _mongoc_cmd_parts_assemble_mongos (mongoc_cmd_parts_t *parts,
 
       bson_concat (&query, &parts->extra);
       if (requires_read_concern) {
-         bson_append_document (
-            &query, "readConcern", 11, &parts->read_concern_document);
+         bson_append_document (&query, "readConcern", 11, &parts->read_concern_document);
       }
 
       if (requires_write_concern) {
-         bson_append_document (
-            &query, "writeConcern", 12, &parts->write_concern_document);
+         bson_append_document (&query, "writeConcern", 12, &parts->write_concern_document);
       }
 
       bson_append_document_end (&parts->assembled_body, &query);
-      _mongoc_cmd_parts_add_read_prefs (&parts->assembled_body,
-                                        parts->read_prefs);
+      _mongoc_cmd_parts_add_read_prefs (&parts->assembled_body, parts->read_prefs);
 
       if (has_dollar_query) {
          /* copy anything that isn't in user's $query */
-         bson_copy_to_excluding_noinit (
-            parts->body, &parts->assembled_body, "$query", NULL);
+         bson_copy_to_excluding_noinit (parts->body, &parts->assembled_body, "$query", NULL);
       }
 
       parts->assembled.command = &parts->assembled_body;
@@ -509,28 +477,22 @@ _mongoc_cmd_parts_assemble_mongos (mongoc_cmd_parts_t *parts,
       _iter_concat (&query, &dollar_query);
       bson_concat (&query, &parts->extra);
       if (requires_read_concern) {
-         bson_append_document (
-            &query, "readConcern", 11, &parts->read_concern_document);
+         bson_append_document (&query, "readConcern", 11, &parts->read_concern_document);
       }
 
       if (requires_write_concern) {
-         bson_append_document (
-            &query, "writeConcern", 12, &parts->write_concern_document);
+         bson_append_document (&query, "writeConcern", 12, &parts->write_concern_document);
       }
 
       bson_append_document_end (&parts->assembled_body, &query);
       /* copy anything that isn't in user's $query */
-      bson_copy_to_excluding_noinit (
-         parts->body, &parts->assembled_body, "$query", NULL);
+      bson_copy_to_excluding_noinit (parts->body, &parts->assembled_body, "$query", NULL);
 
       parts->assembled.command = &parts->assembled_body;
    } else {
       if (requires_read_concern) {
          _mongoc_cmd_parts_ensure_copied (parts);
-         bson_append_document (&parts->assembled_body,
-                               "readConcern",
-                               11,
-                               &parts->read_concern_document);
+         bson_append_document (&parts->assembled_body, "readConcern", 11, &parts->read_concern_document);
       }
 
       _mongoc_cmd_parts_add_write_concern (parts);
@@ -546,8 +508,7 @@ _mongoc_cmd_parts_assemble_mongos (mongoc_cmd_parts_t *parts,
 
 
 static void
-_mongoc_cmd_parts_assemble_mongod (mongoc_cmd_parts_t *parts,
-                                   const mongoc_server_stream_t *server_stream)
+_mongoc_cmd_parts_assemble_mongod (mongoc_cmd_parts_t *parts, const mongoc_server_stream_t *server_stream)
 {
    ENTRY;
 
@@ -570,8 +531,7 @@ _mongoc_cmd_parts_assemble_mongod (mongoc_cmd_parts_t *parts,
           * request. Clients MUST  NOT set the secondaryOk wire protocol flag if
           * the read preference mode is primary.
           */
-         if (parts->read_prefs &&
-             parts->read_prefs->mode != MONGOC_READ_PRIMARY) {
+         if (parts->read_prefs && parts->read_prefs->mode != MONGOC_READ_PRIMARY) {
             parts->assembled.query_flags |= MONGOC_QUERY_SECONDARY_OK;
          }
 
@@ -591,13 +551,9 @@ _mongoc_cmd_parts_assemble_mongod (mongoc_cmd_parts_t *parts,
       _mongoc_cmd_parts_ensure_copied (parts);
    }
 
-   if (!bson_empty (&parts->read_concern_document) &&
-       strcmp (parts->assembled.command_name, "getMore") != 0) {
+   if (!bson_empty (&parts->read_concern_document) && strcmp (parts->assembled.command_name, "getMore") != 0) {
       _mongoc_cmd_parts_ensure_copied (parts);
-      bson_append_document (&parts->assembled_body,
-                            "readConcern",
-                            11,
-                            &parts->read_concern_document);
+      bson_append_document (&parts->assembled_body, "readConcern", 11, &parts->read_concern_document);
    }
 
    _mongoc_cmd_parts_add_write_concern (parts);
@@ -640,12 +596,10 @@ _largest_cluster_time (const bson_t *a, const bson_t *b)
  * documentation already instructs users not to use that for basic writes.
  */
 static bool
-_allow_txn_number (const mongoc_cmd_parts_t *parts,
-                   const mongoc_server_stream_t *server_stream)
+_allow_txn_number (const mongoc_cmd_parts_t *parts, const mongoc_server_stream_t *server_stream)
 {
    /* There is no reason to call this function if allow_txn_number is set */
-   BSON_ASSERT (parts->allow_txn_number ==
-                MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_UNKNOWN);
+   BSON_ASSERT (parts->allow_txn_number == MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_UNKNOWN);
 
    if (!parts->is_write_command) {
       return false;
@@ -669,8 +623,7 @@ _allow_txn_number (const mongoc_cmd_parts_t *parts,
 
 /* Check if the write command should support retryable behavior. */
 static bool
-_is_retryable_write (const mongoc_cmd_parts_t *parts,
-                     const mongoc_server_stream_t *server_stream)
+_is_retryable_write (const mongoc_cmd_parts_t *parts, const mongoc_server_stream_t *server_stream)
 {
    if (!parts->assembled.session) {
       return false;
@@ -696,9 +649,7 @@ _is_retryable_write (const mongoc_cmd_parts_t *parts,
       return false;
    }
 
-   if (!mongoc_uri_get_option_as_bool (parts->client->uri,
-                                       MONGOC_URI_RETRYWRITES,
-                                       MONGOC_DEFAULT_RETRYWRITES)) {
+   if (!mongoc_uri_get_option_as_bool (parts->client->uri, MONGOC_URI_RETRYWRITES, MONGOC_DEFAULT_RETRYWRITES)) {
       return false;
    }
 
@@ -708,8 +659,7 @@ _is_retryable_write (const mongoc_cmd_parts_t *parts,
 
 /* Check if the read command should support retryable behavior. */
 bool
-_is_retryable_read (const mongoc_cmd_parts_t *parts,
-                    const mongoc_server_stream_t *server_stream)
+_is_retryable_read (const mongoc_cmd_parts_t *parts, const mongoc_server_stream_t *server_stream)
 {
    if (!parts->is_read_command) {
       return false;
@@ -729,9 +679,7 @@ _is_retryable_read (const mongoc_cmd_parts_t *parts,
       return false;
    }
 
-   if (!mongoc_uri_get_option_as_bool (parts->client->uri,
-                                       MONGOC_URI_RETRYREADS,
-                                       MONGOC_DEFAULT_RETRYREADS)) {
+   if (!mongoc_uri_get_option_as_bool (parts->client->uri, MONGOC_URI_RETRYREADS, MONGOC_DEFAULT_RETRYREADS)) {
       return false;
    }
 
@@ -760,9 +708,7 @@ _is_retryable_read (const mongoc_cmd_parts_t *parts,
  */
 
 bool
-mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
-                           mongoc_server_stream_t *server_stream,
-                           bson_error_t *error)
+mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts, mongoc_server_stream_t *server_stream, bson_error_t *error)
 {
    mongoc_server_description_type_t server_type;
    mongoc_client_session_t *cs;
@@ -805,26 +751,20 @@ mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
    /* unused in OP_MSG: */
    parts->assembled.query_flags = parts->user_query_flags;
    parts->assembled.server_stream = server_stream;
-   cmd_name = parts->assembled.command_name =
-      _mongoc_get_command_name (parts->assembled.command);
+   cmd_name = parts->assembled.command_name = _mongoc_get_command_name (parts->assembled.command);
 
    if (!parts->assembled.command_name) {
-      bson_set_error (error,
-                      MONGOC_ERROR_COMMAND,
-                      MONGOC_ERROR_COMMAND_INVALID_ARG,
-                      "Empty command document");
+      bson_set_error (error, MONGOC_ERROR_COMMAND, MONGOC_ERROR_COMMAND_INVALID_ARG, "Empty command document");
       GOTO (done);
    }
 
    TRACE ("Preparing '%s'", cmd_name);
 
    is_get_more = !strcmp (cmd_name, "getMore");
-   parts->assembled.is_txn_finish = !strcmp (cmd_name, "commitTransaction") ||
-                                    !strcmp (cmd_name, "abortTransaction");
+   parts->assembled.is_txn_finish = !strcmp (cmd_name, "commitTransaction") || !strcmp (cmd_name, "abortTransaction");
 
    if (!parts->is_write_command && IS_PREF_PRIMARY (parts->read_prefs) &&
-       server_stream->topology_type == MONGOC_TOPOLOGY_SINGLE &&
-       server_type != MONGOC_SERVER_MONGOS) {
+       server_stream->topology_type == MONGOC_TOPOLOGY_SINGLE && server_type != MONGOC_SERVER_MONGOS) {
       prefs = mongoc_read_prefs_new (MONGOC_READ_PRIMARY_PREFERRED);
       prefs_ptr = prefs;
    } else {
@@ -839,24 +779,21 @@ mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
       mode = MONGOC_READ_PRIMARY;
    }
 
-   if (mongoc_client_uses_server_api (parts->client) ||
-       mongoc_client_uses_loadbalanced (parts->client) ||
+   if (mongoc_client_uses_server_api (parts->client) || mongoc_client_uses_loadbalanced (parts->client) ||
        server_stream->sd->max_wire_version >= WIRE_VERSION_MIN) {
       if (!bson_has_field (parts->body, "$db")) {
          BSON_APPEND_UTF8 (&parts->extra, "$db", parts->assembled.db_name);
       }
 
       if (cs && _mongoc_client_session_in_txn (cs)) {
-         if (!IS_PREF_PRIMARY (cs->txn.opts.read_prefs) &&
-             !parts->is_write_command) {
+         if (!IS_PREF_PRIMARY (cs->txn.opts.read_prefs) && !parts->is_write_command) {
             bson_set_error (error,
                             MONGOC_ERROR_TRANSACTION,
                             MONGOC_ERROR_TRANSACTION_INVALID_STATE,
                             "Read preference in a transaction must be primary");
             GOTO (done);
          }
-      } else if (mode != MONGOC_READ_PRIMARY &&
-                 server_type != MONGOC_SERVER_STANDALONE) {
+      } else if (mode != MONGOC_READ_PRIMARY && server_type != MONGOC_SERVER_STANDALONE) {
          /* "Type Standalone: clients MUST NOT send the read preference to the
           * server" */
          _mongoc_cmd_parts_add_read_prefs (&parts->extra, prefs_ptr);
@@ -886,32 +823,25 @@ mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
        */
       if (cs) {
          if (!parts->assembled.is_acknowledged) {
-            bson_set_error (
-               error,
-               MONGOC_ERROR_COMMAND,
-               MONGOC_ERROR_COMMAND_INVALID_ARG,
-               "Cannot use client session with unacknowledged command");
+            bson_set_error (error,
+                            MONGOC_ERROR_COMMAND,
+                            MONGOC_ERROR_COMMAND_INVALID_ARG,
+                            "Cannot use client session with unacknowledged command");
             GOTO (done);
          }
 
          _mongoc_cmd_parts_ensure_copied (parts);
-         bson_append_document (&parts->assembled_body,
-                               "lsid",
-                               4,
-                               mongoc_client_session_get_lsid (cs));
+         bson_append_document (&parts->assembled_body, "lsid", 4, mongoc_client_session_get_lsid (cs));
 
          cs->server_session->last_used_usec = bson_get_monotonic_time ();
          cluster_time = mongoc_client_session_get_cluster_time (cs);
       }
 
       /* Ensure we know if the write command allows a transaction number */
-      if (!_mongoc_client_session_txn_in_progress (cs) &&
-          parts->is_write_command &&
-          parts->allow_txn_number ==
-             MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_UNKNOWN) {
-         parts->allow_txn_number = _allow_txn_number (parts, server_stream)
-                                      ? MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_YES
-                                      : MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_NO;
+      if (!_mongoc_client_session_txn_in_progress (cs) && parts->is_write_command &&
+          parts->allow_txn_number == MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_UNKNOWN) {
+         parts->allow_txn_number = _allow_txn_number (parts, server_stream) ? MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_YES
+                                                                            : MONGOC_CMD_PARTS_ALLOW_TXN_NUMBER_NO;
       }
 
       /* Determine if the command is retryable. If so, append txnNumber now
@@ -928,20 +858,17 @@ mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
       }
 
       if (!bson_empty (&server_stream->cluster_time)) {
-         cluster_time =
-            _largest_cluster_time (&server_stream->cluster_time, cluster_time);
+         cluster_time = _largest_cluster_time (&server_stream->cluster_time, cluster_time);
       }
 
       if (cluster_time && server_type != MONGOC_SERVER_STANDALONE) {
          _mongoc_cmd_parts_ensure_copied (parts);
-         bson_append_document (
-            &parts->assembled_body, "$clusterTime", 12, cluster_time);
+         bson_append_document (&parts->assembled_body, "$clusterTime", 12, cluster_time);
       }
 
       /* Add versioned server api, if it is set. */
       if (mongoc_client_uses_server_api (parts->client)) {
-         _mongoc_cmd_append_server_api (&parts->assembled_body,
-                                        parts->client->api);
+         _mongoc_cmd_append_server_api (&parts->assembled_body, parts->client->api);
       }
 
       if (!is_get_more) {
@@ -950,8 +877,7 @@ mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
              * Throw an error if snapshot is enabled and wire version is less
              * than 13 before potentially appending "snapshot" read concern. */
             if (mongoc_session_opts_get_snapshot (&cs->opts) &&
-                server_stream->sd->max_wire_version <
-                   WIRE_VERSION_SNAPSHOT_READS) {
+                server_stream->sd->max_wire_version < WIRE_VERSION_SNAPSHOT_READS) {
                bson_set_error (error,
                                MONGOC_ERROR_CLIENT,
                                MONGOC_ERROR_CLIENT_SESSION_FAILURE,
@@ -961,34 +887,25 @@ mongoc_cmd_parts_assemble (mongoc_cmd_parts_t *parts,
 
             _mongoc_cmd_parts_ensure_copied (parts);
             _mongoc_client_session_append_read_concern (
-               cs,
-               &parts->read_concern_document,
-               parts->is_read_command,
-               &parts->assembled_body);
+               cs, &parts->read_concern_document, parts->is_read_command, &parts->assembled_body);
          } else if (!bson_empty (&parts->read_concern_document)) {
             _mongoc_cmd_parts_ensure_copied (parts);
-            bson_append_document (&parts->assembled_body,
-                                  "readConcern",
-                                  11,
-                                  &parts->read_concern_document);
+            bson_append_document (&parts->assembled_body, "readConcern", 11, &parts->read_concern_document);
          }
       }
 
       /* if transaction is in progress do not inherit write concern */
-      if (parts->assembled.is_txn_finish ||
-          !_mongoc_client_session_in_txn (cs)) {
+      if (parts->assembled.is_txn_finish || !_mongoc_client_session_in_txn (cs)) {
          _mongoc_cmd_parts_add_write_concern (parts);
       }
 
       _mongoc_cmd_parts_ensure_copied (parts);
-      if (!_mongoc_client_session_append_txn (
-             cs, &parts->assembled_body, error)) {
+      if (!_mongoc_client_session_append_txn (cs, &parts->assembled_body, error)) {
          GOTO (done);
       }
 
       ret = true;
-   } else if (server_type == MONGOC_SERVER_MONGOS ||
-              server_stream->topology_type == MONGOC_TOPOLOGY_LOAD_BALANCED) {
+   } else if (server_type == MONGOC_SERVER_MONGOS || server_stream->topology_type == MONGOC_TOPOLOGY_LOAD_BALANCED) {
       /* TODO (CDRIVER-4117) remove the check of the topology description type.
        */
       _mongoc_cmd_parts_assemble_mongos (parts, server_stream);
@@ -1031,42 +948,22 @@ mongoc_cmd_parts_cleanup (mongoc_cmd_parts_t *parts)
 }
 
 bool
-mongoc_cmd_is_compressible (mongoc_cmd_t *cmd)
+mongoc_cmd_is_compressible (const mongoc_cmd_t *cmd)
 {
    BSON_ASSERT (cmd);
    BSON_ASSERT (cmd->command_name);
 
-   return !!strcasecmp (cmd->command_name, "hello") &&
-          !!strcasecmp (cmd->command_name, HANDSHAKE_CMD_LEGACY_HELLO) &&
-          !!strcasecmp (cmd->command_name, "authenticate") &&
-          !!strcasecmp (cmd->command_name, "getnonce") &&
-          !!strcasecmp (cmd->command_name, "saslstart") &&
-          !!strcasecmp (cmd->command_name, "saslcontinue") &&
-          !!strcasecmp (cmd->command_name, "createuser") &&
-          !!strcasecmp (cmd->command_name, "updateuser");
+   return !!strcasecmp (cmd->command_name, "hello") && !!strcasecmp (cmd->command_name, HANDSHAKE_CMD_LEGACY_HELLO) &&
+          !!strcasecmp (cmd->command_name, "authenticate") && !!strcasecmp (cmd->command_name, "getnonce") &&
+          !!strcasecmp (cmd->command_name, "saslstart") && !!strcasecmp (cmd->command_name, "saslcontinue") &&
+          !!strcasecmp (cmd->command_name, "createuser") && !!strcasecmp (cmd->command_name, "updateuser");
 }
 
-/*--------------------------------------------------------------------------
- *
- * _mongoc_cmd_append_payload_as_array --
- *    Append a write command payload as an array in a BSON document.
- *    Used by APM and Client-Side Encryption
- *
- * Arguments:
- *    cmd The mongoc_cmd_t, which may contain a payload to be appended.
- *    out A bson_t, which will be appended to if @cmd->payload is set.
- *
- * Pre-conditions:
- *    - @out is initialized.
- *    - cmd has a payload (i.e. is a write command).
- *
- * Post-conditions:
- *    - If @cmd->payload is set, then @out is appended to with the payload
- *      field's name ("documents" if insert, "updates" if update,
- *      "deletes" if delete) an the payload as a BSON array.
- *
- *--------------------------------------------------------------------------
- */
+
+//`_mongoc_cmd_append_payload_as_array` appends document seqence payloads as BSON arrays.
+// `cmd` must contain one or more document sequence payloads (`cmd->payloads_count` > 0).
+// `out` must be initialized by the caller.
+// Used by APM and In-Use Encryption (document sequences are not supported for auto encryption).
 void
 _mongoc_cmd_append_payload_as_array (const mongoc_cmd_t *cmd, bson_t *out)
 {
@@ -1076,25 +973,28 @@ _mongoc_cmd_append_payload_as_array (const mongoc_cmd_t *cmd, bson_t *out)
    const char *field_name;
    bson_array_builder_t *bson;
 
-   BSON_ASSERT (cmd->payload && cmd->payload_size);
+   BSON_ASSERT (cmd->payloads_count > 0);
+   BSON_ASSERT (cmd->payloads_count <= MONGOC_CMD_PAYLOADS_COUNT_MAX);
 
-   /* make array from outgoing OP_MSG payload type 1 on an "insert",
-    * "update", or "delete" command. */
-   field_name = _mongoc_get_documents_field_name (cmd->command_name);
-   BSON_ASSERT (field_name);
-   BSON_ASSERT (BSON_APPEND_ARRAY_BUILDER_BEGIN (out, field_name, &bson));
+   for (size_t i = 0; i < cmd->payloads_count; i++) {
+      BSON_ASSERT (cmd->payloads[i].documents && cmd->payloads[i].size);
 
-   pos = cmd->payload;
-   while (pos < cmd->payload + cmd->payload_size) {
-      memcpy (&doc_len, pos, sizeof (doc_len));
-      doc_len = BSON_UINT32_FROM_LE (doc_len);
-      BSON_ASSERT (bson_init_static (&doc, pos, (size_t) doc_len));
-      bson_array_builder_append_document (bson, &doc);
+      // Create a BSON array from a document sequence (OP_MSG Section with payloadType=1).
+      field_name = cmd->payloads[i].identifier;
+      BSON_ASSERT (field_name);
+      BSON_ASSERT (BSON_APPEND_ARRAY_BUILDER_BEGIN (out, field_name, &bson));
 
-      pos += doc_len;
+      pos = cmd->payloads[i].documents;
+      while (pos < cmd->payloads[i].documents + cmd->payloads[i].size) {
+         memcpy (&doc_len, pos, sizeof (doc_len));
+         doc_len = BSON_UINT32_FROM_LE (doc_len);
+         BSON_ASSERT (bson_init_static (&doc, pos, (size_t) doc_len));
+         bson_array_builder_append_document (bson, &doc);
+
+         pos += doc_len;
+      }
+      bson_append_array_builder_end (out, bson);
    }
-
-   bson_append_array_builder_end (out, bson);
 }
 
 /*--------------------------------------------------------------------------
@@ -1113,8 +1013,7 @@ _mongoc_cmd_append_payload_as_array (const mongoc_cmd_t *cmd, bson_t *out)
  *--------------------------------------------------------------------------
  */
 void
-_mongoc_cmd_append_server_api (bson_t *command_body,
-                               const mongoc_server_api_t *api)
+_mongoc_cmd_append_server_api (bson_t *command_body, const mongoc_server_api_t *api)
 {
    const char *string_version;
 
@@ -1132,9 +1031,6 @@ _mongoc_cmd_append_server_api (bson_t *command_body,
    }
 
    if (api->deprecation_errors.is_set) {
-      bson_append_bool (command_body,
-                        "apiDeprecationErrors",
-                        -1,
-                        api->deprecation_errors.value);
+      bson_append_bool (command_body, "apiDeprecationErrors", -1, api->deprecation_errors.value);
    }
 }
