@@ -113,9 +113,7 @@ make_uri (mongoc_array_t *servers)
 
 
 static char *
-hello_json (mock_rs_t *rs,
-            mongoc_server_description_type_t type,
-            const bson_t *tags)
+hello_json (mock_rs_t *rs, mongoc_server_description_type_t type, const bson_t *tags)
 {
    char *server_type;
    char *tags_json;
@@ -139,28 +137,27 @@ hello_json (mock_rs_t *rs,
 
    hosts_str = hosts (&rs->servers);
 
-   json = bson_strdup_printf (
-      "{'ok': 1,"
-      " %s"
-      " '$clusterTime': {"
-      "   'clusterTime': {'$timestamp': {'t': 1, 'i': 1}},"
-      "   'signature': {"
-      "     'hash': {'$binary': {'subType': '0', 'base64': ''}},"
-      "     'keyId': {'$numberLong': '6446735049323708417'}"
-      "   },"
-      "   'operationTime': {'$timestamp': {'t': 1, 'i': 1}}"
-      " },"
-      "'logicalSessionTimeoutMinutes': 30,"
-      " 'tags': %s,"
-      " 'minWireVersion': %d,"
-      " 'maxWireVersion': %d,"
-      " 'setName': 'rs',"
-      " 'hosts': [%s]}",
-      server_type,
-      tags_json,
-      WIRE_VERSION_MIN,
-      rs->max_wire_version,
-      hosts_str);
+   json = bson_strdup_printf ("{'ok': 1,"
+                              " %s"
+                              " '$clusterTime': {"
+                              "   'clusterTime': {'$timestamp': {'t': 1, 'i': 1}},"
+                              "   'signature': {"
+                              "     'hash': {'$binary': {'subType': '0', 'base64': ''}},"
+                              "     'keyId': {'$numberLong': '6446735049323708417'}"
+                              "   },"
+                              "   'operationTime': {'$timestamp': {'t': 1, 'i': 1}}"
+                              " },"
+                              "'logicalSessionTimeoutMinutes': 30,"
+                              " 'tags': %s,"
+                              " 'minWireVersion': %d,"
+                              " 'maxWireVersion': %d,"
+                              " 'setName': 'rs',"
+                              " 'hosts': [%s]}",
+                              server_type,
+                              tags_json,
+                              WIRE_VERSION_MIN,
+                              rs->max_wire_version,
+                              hosts_str);
 
    bson_free (tags_json);
    bson_free (hosts_str);
@@ -179,8 +176,7 @@ primary_json (mock_rs_t *rs)
 static char *
 secondary_json (mock_rs_t *rs, int server_number)
 {
-   return hello_json (
-      rs, MONGOC_SERVER_RS_SECONDARY, rs->secondary_tags[server_number]);
+   return hello_json (rs, MONGOC_SERVER_RS_SECONDARY, rs->secondary_tags[server_number]);
 }
 
 
@@ -208,17 +204,13 @@ arbiter_json (mock_rs_t *rs)
  */
 
 mock_rs_t *
-mock_rs_with_auto_hello (int32_t max_wire_version,
-                         bool has_primary,
-                         int n_secondaries,
-                         int n_arbiters)
+mock_rs_with_auto_hello (int32_t max_wire_version, bool has_primary, int n_secondaries, int n_arbiters)
 {
    int i;
    mock_rs_t *rs = BSON_ALIGNED_ALLOC0 (mock_rs_t);
 
    ASSERT_WITH_MSG (max_wire_version >= WIRE_VERSION_MIN,
-                    "max_wire_version %" PRId32
-                    " must be greater than or equal to minimum wire version %d",
+                    "max_wire_version %" PRId32 " must be greater than or equal to minimum wire version %d",
                     max_wire_version,
                     WIRE_VERSION_MIN);
 
@@ -344,8 +336,7 @@ mock_rs_run (mock_rs_t *rs)
     * runs last, after auto_hello.
     */
    for (size_t i = 0u; i < rs->servers.len; i++) {
-      mock_server_autoresponds (
-         get_server (&rs->servers, i), rs_q_append, (void *) rs, NULL);
+      mock_server_autoresponds (get_server (&rs->servers, i), rs_q_append, (void *) rs, NULL);
    }
 
 
@@ -454,8 +445,7 @@ _mock_rs_receives_msg (mock_rs_t *rs, uint32_t flags, ...)
 
    request = (request_t *) q_get (rs->q, rs->request_timeout_msec);
 
-   ASSERT_WITH_MSG (request,
-                    "expected an OP_MSG request but did not receive one!");
+   ASSERT_WITH_MSG (request, "expected an OP_MSG request but did not receive one!");
 
    va_start (args, flags);
    r = request_matches_msgv (request, flags, &args);
@@ -551,8 +541,7 @@ mock_rs_request_is_to_primary (mock_rs_t *rs, request_t *request)
 {
    BSON_ASSERT (request);
 
-   return MONGOC_SERVER_RS_PRIMARY ==
-          _mock_rs_server_type (rs, request_get_server_port (request));
+   return MONGOC_SERVER_RS_PRIMARY == _mock_rs_server_type (rs, request_get_server_port (request));
 }
 
 
@@ -577,8 +566,7 @@ mock_rs_request_is_to_secondary (mock_rs_t *rs, request_t *request)
 {
    BSON_ASSERT (request);
 
-   return MONGOC_SERVER_RS_SECONDARY ==
-          _mock_rs_server_type (rs, request_get_server_port (request));
+   return MONGOC_SERVER_RS_SECONDARY == _mock_rs_server_type (rs, request_get_server_port (request));
 }
 
 
@@ -598,8 +586,7 @@ mock_rs_stepdown (mock_rs_t *rs)
 
    BSON_ASSERT (rs->primary);
    rs->n_secondaries++;
-   rs->secondary_tags =
-      bson_realloc (rs->secondary_tags, rs->n_secondaries * sizeof (bson_t *));
+   rs->secondary_tags = bson_realloc (rs->secondary_tags, rs->n_secondaries * sizeof (bson_t *));
 
    rs->secondary_tags[rs->n_secondaries - 1] = bson_copy (&rs->primary_tags);
    bson_reinit (&rs->primary_tags);
